==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Effect/ladspa/translations/ladspa_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>EffectLADSPAFactory</name>
    <message>
        <location filename="../effectladspafactory.cpp" line="31"/>
        <source>LADSPA Plugin</source>
        <translation>LADSPA 外掛</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="51"/>
        <source>About LADSPA Host for Qmmp</source>
        <translation>關於 Qmmp LADSPA 主机</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="52"/>
        <source>LADSPA Host for Qmmp</source>
        <translation>Qmmp 的 LADSPA 主机</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="54"/>
        <source>Based on the LADSPA Host for BMP</source>
        <translation>基於 BMP 的 LADSPA 主机</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="55"/>
        <source>BMP-ladspa developers:</source>
        <translation>BMP-ladspa 開發者：</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="56"/>
        <source>Nick Lamb &lt;njl195@zepler.org.uk&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="57"/>
        <source>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>LADSPA Plugin Catalog</source>
        <translation>LADSPA 插件目錄</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Configure</source>
        <translation>配置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>UID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>This LADSPA plugin has no user controls</source>
        <translation>LADSPA 插件用戶設定</translation>
    </message>
</context>
</TS>

==> qmmp-1.0.7.tar.bz2: qmmp-1.0.7/src/plugins/Effect/ladspa/translations/ladspa_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN" sourcelanguage="zh_TW">
<context>
    <name>EffectLADSPAFactory</name>
    <message>
        <location filename="../effectladspafactory.cpp" line="31"/>
        <source>LADSPA Plugin</source>
        <translation>LADSPA 插件</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="51"/>
        <source>About LADSPA Host for Qmmp</source>
        <translation>關於 Qmmp LADSPA 主机</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="52"/>
        <source>LADSPA Host for Qmmp</source>
        <translation>Qmmp 的 LADSPA 主机</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="54"/>
        <source>Based on the LADSPA Host for BMP</source>
        <translation>基於 BMP 的 LADSPA 主机</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="55"/>
        <source>BMP-ladspa developers:</source>
        <translation>BMP-ladspa 開發者：</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="56"/>
        <source>Nick Lamb &lt;njl195@zepler.org.uk&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="57"/>
        <source>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>UID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="128"/>
        <source>This LADSPA plugin has no user controls</source>
        <translation>LADSPA 插件用戶設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>LADSPA Plugin Catalog</source>
        <translation>LADSPA 插件目錄</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Configure</source>
        <translation>配置</translation>
    </message>
</context>
</TS>
